@@ -1,7 +1,7 @@
-# $Id: ODBC.pm,v 1.12 1998/08/14 19:29:50 timbo Exp $
+# $Id: ODBC.pm 9700 2007-07-04 14:12:58Z mjevans $
 #
 # Copyright (c) 1994,1995,1996,1998  Tim Bunce
-# portions Copyright (c) 1997,1998,1999,2000,2001,2002  Jeff Urlwin
+# portions Copyright (c) 1997-2004  Jeff Urlwin
 # portions Copyright (c) 1997  Thomas K. Wenrich
 #
 # You may distribute under the terms of either the GNU General Public
@@ -9,19 +9,20 @@
 
 require 5.004;
 
-$DBD::ODBC::VERSION = '1.00';
+$DBD::ODBC::VERSION = '1.14_1';
 
 {
     package DBD::ODBC;
 
     use DBI ();
     use DynaLoader ();
+    use Exporter ();
+    
+    @ISA = qw(Exporter DynaLoader);
 
-    @ISA = qw(DynaLoader);
+    # my $Revision = substr(q$Id: ODBC.pm 9700 2007-07-04 14:12:58Z mjevans $, 13,2);
 
-    my $Revision = substr(q$Revision: 1.12 $, 10);
-
-    require_version DBI 1.201;
+    require_version DBI 1.21;
 
     bootstrap DBD::ODBC $VERSION;
 
@@ -269,7 +270,6 @@ $DBD::ODBC::VERSION = '1.00';
     sub do {
         my($dbh, $statement, $attr, @params) = @_;
         my $rows = 0;
-
         if( -1 == $#params )
         {
           # No parameters, use execute immediate
@@ -421,11 +421,16 @@ See L<DBI> for more information.
 =head2 Notes:
 
 =over 4
+
 =item B<Change log/recent updates now in DBD::ODBC::Changes.pm>
 
  Please note that the change log has been moved to DBD::ODBC::Changes.pm
  To easily access this documentation, use perldoc DBD::ODBC::Changes
- 
+
+ Also, while this document documents features, etc, I'm really trying to keep
+ the FAQ type questions answered in the DBI FAQ itself... see
+ http://dbi.perl.org for more information.
+   
 =item B<An Important note about the tests!>
 
  Please note that some tests may fail or report they are
@@ -441,7 +446,47 @@ See L<DBI> for more information.
  t/09multi.t, if your driver doesn't seem to support
  returning multiple result sets.  This is normal.
 
+=item B<Version Control>
+
+ I have recently placed all of the DBD::ODBC source code
+ under version control at svn.perl.org.  If you would like
+ to use the "bleeding" edge version, you can get the latest
+ from svn.perl.org via Subversion version control.  Note that I
+ don't guarantee that this version is any different than what
+ you get from the tarball from CPAN, but hey, it might be :)
+
+ You may read about Subversion from:
+   http://subversion.tigris.org
+
+ You can get a subversion client from there and check dbd-odbc out via:
+
+   svn checkout http://svn.perl.org/modules/dbd-odbc/trunk <your directory name here>
+
+ Which will, after a short bit a of work, grab all the files into your
+ local directory tree that you name.  For now, you can authenticate via the guest
+ user and guest password.  That will change to be unauthenticated in the future for
+ simple read-only checkout.
+				    
+=item B<Contributing>
+
+ I am usually very open to contributions, but I have tended
+ to get behind.  That's one strong reason why I've put everything
+ in a shared version control environment.
+
+ Please use Subversion (see above) to appropriately get the latest
+ versions.
+
+ Please, before submitting a patch:
+    svn update
+    <test your patch>
+    svn diff > describe_my_diffs.patch
+
+ and send the resuting file to me...
+
+ It's probably best to send to dbi-users@perl.org, as I monitor that group.
+ 
 =item B<Private DBD::ODBC Attributes>
+
 =item odbc_more_results (applies to statement handle only!)
 
 Use this attribute to determine if there are more result sets
@@ -503,9 +548,9 @@ There are drivers that only support SQLExecDirect and the DBD::ODBC
 do() override doesn't allow returning result sets.  Therefore, the
 way to do this now is to set the attributed odbc_exec_direct.
 There are currently two ways to get this:
-	$dbh->prepare($sql, { odbc_execdirect => 1}); 
+	$dbh->prepare($sql, { odbc_exec_direct => 1}); 
  and
-	$dbh->{odbc_execdirect} = 1;
+	$dbh->{odbc_exec_direct} = 1;
  When $dbh->prepare() is called with the attribute "ExecDirect" set to a non-zero value 
  dbd_st_prepare do NOT call SQLPrepare, but set the sth flag odbc_exec_direct to 1.
  
@@ -515,6 +560,13 @@ Allow errors to be handled by the application.  A call-back function supplied
 by the application to handle or ignore messages.  If the error handler returns
 0, the error is ignored, otherwise the error is passed through the normal
 DBI error handling structure(s).
+
+This can also be used for procedures under MS SQL Server (Sybase too, probably)
+to obtain messages from system procedures such as DBCC.  Check t/20SQLServer.t
+and mytest/testerrhandler.pl
+
+The callback function takes three parameters: the SQLState, the ErrorMessage and
+the native server error.
  
 =item odbc_SQL_ROWSET_SIZE
 
@@ -550,11 +602,87 @@ SQL_ROWSET_SIZE attribute patch from Andrew Brown
 This, while available via get_info() is captured here.  I may get rid of this
 as I only used it for debugging purposes.  
  
-=item odbc_version
+=item odbc_cursortype (applies to connect only!)
+
+This allows multiple concurrent statements on SQL*Server.  In your connect, add
+{ odbc_cursortype => 2 }.  If you are using DBI > 1.41, you should also be able
+to use { odbc_cursortype => DBI::SQL_CURSOR_DYNAMIC } instead.  For example:
+
+ my $dbh = DBI->connect("dbi:ODBC:$DSN", $user, $pass, { RaiseError => 1, odbc_cursortype => 2});
+ my $sth = $dbh->prepare("one statement");
+ my $sth2 = $dbh->prepare("two statement");
+ $sth->execute;
+ my @row;
+ while (@row = $sth->fetchrow_array) {
+    $sth2->execute($row[0]);
+ }
+
+See t/20SqlServer.t for an example.
+
+
+=item odbc_query_timeout 
+
+This allows the end user to set a timeout for queries on the ODBC side.  After your connect, add
+{ odbc_query_timeout => 30 } or set on the dbh before executing the statement.  The default is 0, no timeout.
+Note that some drivers may not support this attribute.
+
+See t/20SqlServer.t for an example.
+
+=item odbc_has_unicode (applies to database handle only)
+
+A read-only attribute signifying whether DBD::ODBC was built with the
+C macro WITH_UNICODE or not. A value of 1 indicates DBD::ODBC was built
+with WITH_UNICODE else the value returned is 0.
+
+Building WITH_UNICODE affects columns and parameters which are
+SQL_C_WCHAR, SQL_WCHAR, SQL_WVARCHAR, and SQL_WLONGVARCHAR.
+
+When odbc_has_unicode is 1, DBD::ODBC will:
+
+=over 8
+
+=item bind columns the database declares as wide characters as SQL_Wxxx
+
+This means that UNICODE data stored in these columns will be returned
+to Perl in UTF-8 and with the UTF8 flag set.
+
+=item bind parameters the database declares as wide characters as SQL_Wxxx
+
+Parameters bound where the database declares the parameter as being
+a wide character (or where the parameter type is explicitly set to a
+wide type - SQL_Wxxx) can be UTF8 in Perl and will be mapped to UTF16
+before passing to the driver.
+
+=back
+
+NOTE: You will need at least Perl 5.8.1 to use UNICODE with DBD::ODBC.
+
+NOTE: At this time SQL statements are still treated as native encoding
+i.e. DBD::ODBC does not call SQLPrepareW with UNICODE strings. If you
+need a unicode constant in an SQL statement, you have to pass it as
+parameter or use SQL functions to convert your constant from native
+encoding to Unicode.
+
+NOTE: Binding of unicode output parameters is coded but untested.
+
+NOTE: When building DBD::ODBC on Windows ($^O eq 'MSWin32) the 
+WITH_UNICODE macro is automatically added. To disable specify -nou as
+an argument to Makefile.PL (e.g. nmake Makefile.PL -nou). On non-Windows
+platforms the WITH_UNICODE macro is B<not> enabled by default and to enable
+you need to specify the -u argument to Makefile.PL. Please bare in mind
+that some ODBC drivers do not support SQL_Wxxx columns or parameters.
+
+UNICODE support in ODBC Drivers differs considerably. Please read the
+README.unicode file for further details.
+
+=item odbc_version (applies to connect only!)
 
 This was added prior to the move to ODBC 3.x to allow the caller to "force" ODBC 3.0
 compatibility.  It's probably not as useful now, but it allowed get_info and get_type_info
 to return correct/updated information that ODBC 2.x didn't permit/provide.
+Since DBD::ODBC is now 3.x, this can be used to force 2.x behavior via something like:
+  my $dbh = DBI->connect("dbi:ODBC:$DSN", $user, $pass, { odbc_version => 2});
+       
    
 =item B<Private DBD::ODBC Functions>
 
@@ -723,6 +851,8 @@ Example (using MSSQL Server):
       database=database_name;uid=user;pwd=password;';
       my $dbh  = DBI->connect("dbi:ODBC:$DSN") or die "$DBI::errstr\n";
 
+=back
+
 =head2 Random Links
 
 These are in need of sorting and annotating. Some are relevant only
@@ -743,17 +873,25 @@ to ODBC developers (but I don't want to loose them).
 
         http://www.iodbc.org		iODBC driver manager source
 
-   Also, for Linux folks, you can checkout the following for another ODBC-ODBC bridge and support for iODBC.
+   For Linux/Unix folks, you can checkout the following for another ODBC-ODBC bridge and support for iODBC.
 
 	http://www.openlink.co.uk 
 		or
 	http://www.openlinksw.com 
 
+   And another:
+        OpenRDA
+   
+        http://www.atinet.com/support/openrda_samples.asp
+ 
 
 
 =head2 Frequently Asked Questions
+
 Answers to common DBI and DBD::ODBC questions:
 
+=over 4
+ 
 =item How do I read more than N characters from a Memo | BLOB | LONG field?
 
 See LongReadLen in the DBI docs.  
@@ -777,6 +915,7 @@ you may find something useful at:
 	http://www.openlinksw.com
         http://www.easysoft.com
 	http://www.intersolv.com
+	http://www.atinet.com/support/openrda_samples.asp
 	      
 
 2) ODBC Driver Manager - the piece of software which interacts with the drivers
